==> mingw-w64-tgui-1.3.0-1.src.tar.zst: TGUI-1.3.0/gui-builder/include/WidgetProperties/PanelListBoxProperties.hpp <==
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
// TGUI - Texus' Graphical User Interface
// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


#ifndef TGUI_GUI_BUILDER_PANEL_LIST_BOX_PROPERTIES_HPP
#define TGUI_GUI_BUILDER_PANEL_LIST_BOX_PROPERTIES_HPP

#include "ScrollablePanelProperties.hpp"

struct PanelListBoxProperties : ScrollablePanelProperties
{
    void updateProperty(const tgui::Widget::Ptr& widget, const tgui::String& property, const tgui::String& value) const override
    {
        auto panel = widget->cast<tgui::PanelListBox>();
        if (property == "ItemsHeight")
            panel->setItemsHeight(value);
        else if (property == "MaximumItems")
            panel->setMaximumItems(value.toUInt()); // conversion to size_t not possible with tgui::String
        else
            WidgetProperties::updateProperty(widget, property, value);
    }

    TGUI_NODISCARD PropertyValueMapPair initProperties(const tgui::Widget::Ptr& widget) const override
    {
        auto pair = ScrollablePanelProperties::initProperties(widget);
        auto panel = widget->cast<tgui::PanelListBox>();

        pair.first["ItemsHeight"] = {"Layout", panel->getItemsHeight().toString()};
        pair.first["MaximumItems"] = {"size_t", tgui::String::fromNumber(panel->getMaximumItems())};
        return pair;
    }
};

#endif // TGUI_GUI_BUILDER_PANEL_LIST_BOX_PROPERTIES_HPP

==> mingw-w64-tgui-1.4.1-1.src.tar.zst: TGUI-1.4.1/gui-builder/include/WidgetProperties/PanelListBoxProperties.hpp <==
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
// TGUI - Texus' Graphical User Interface
// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


#ifndef TGUI_GUI_BUILDER_PANEL_LIST_BOX_PROPERTIES_HPP
#define TGUI_GUI_BUILDER_PANEL_LIST_BOX_PROPERTIES_HPP

#include "ScrollablePanelProperties.hpp"

struct PanelListBoxProperties : ScrollablePanelProperties
{
    void updateProperty(const tgui::Widget::Ptr& widget, const tgui::String& property, const tgui::String& value) const override
    {
        auto panel = widget->cast<tgui::PanelListBox>();
        if (property == "ItemsHeight")
            panel->setItemsHeight(value);
        else if (property == "MaximumItems")
            panel->setMaximumItems(value.toUInt()); // conversion to size_t not possible with tgui::String
        else
            WidgetProperties::updateProperty(widget, property, value);
    }

    TGUI_NODISCARD PropertyValueMapPair initProperties(const tgui::Widget::Ptr& widget) const override
    {
        auto pair = ScrollablePanelProperties::initProperties(widget);
        auto panel = widget->cast<tgui::PanelListBox>();

        pair.first["ItemsHeight"] = {"Float", tgui::String::fromNumber(panel->getItemsHeight().getValue())};
        pair.first["MaximumItems"] = {"size_t", tgui::String::fromNumber(panel->getMaximumItems())};
        return pair;
    }
};

#endif // TGUI_GUI_BUILDER_PANEL_LIST_BOX_PROPERTIES_HPP
